@@ -41,7 +41,7 @@
 #' @param verbose When reading from a slow connection, this prints some
 #'    output on every iteration so you know its working.
 #' @param options Set parsing options for the libxml2 parser. Zero or more of
-#' \Sexpr[results=rd]{xml2:::describe_options(xml2:::xml_parse_options())}
+#' \Sexpr[results=rd, stage=build]{xml2:::describe_options(xml2:::xml_parse_options())}
 #' @return An XML document. HTML is normalised to valid XML - this may not
 #'   be exactly the same transformation performed by the browser, but it's
 #'   a reasonable approximation.
@@ -66,21 +66,29 @@ read_xml <- function(x, encoding = "", ..., as_html = FALSE, options = "NOBLANKS
 
 #' @export
 #' @rdname read_xml
-read_html <- function(x, encoding = "", ..., options = c("RECOVER", "NOERROR", "NOBLANKS")) {
+read_html <- function(x,
+                      encoding = "",
+                      ...,
+                      options = c("RECOVER", "NOERROR", "NOBLANKS", "HUGE")) {
   UseMethod("read_html")
 }
 
 #' @export
-read_html.default <- function(x, encoding = "", ..., options = c("RECOVER", "NOERROR", "NOBLANKS")) {
+read_html.default <- function(x,
+                              encoding = "",
+                              ...,
+                              options = c("RECOVER", "NOERROR", "NOBLANKS", "HUGE")) {
   options <- parse_options(options, xml_parse_options())
 
   suppressWarnings(read_xml(x, encoding = encoding, ..., as_html = TRUE, options = options))
 }
 
 #' @export
-read_html.response <- function(x, encoding = "", options = c("RECOVER",
-    "NOERROR", "NOBLANKS"), ...) {
-  need_package("httr")
+read_html.response <- function(x,
+                               encoding = "",
+                               options = c("RECOVER", "NOERROR", "NOBLANKS"),
+                               ...) {
+  check_installed("httr")
 
   options <- parse_options(options, xml_parse_options())
 
@@ -91,12 +99,12 @@ read_html.response <- function(x, encoding = "", options = c("RECOVER",
 
 #' @export
 #' @rdname read_xml
-read_xml.character <- function(x, encoding = "", ..., as_html = FALSE,
+read_xml.character <- function(x,
+                               encoding = "",
+                               ...,
+                               as_html = FALSE,
                                options = "NOBLANKS") {
-
-  if (length(x) == 0) {
-    stop("Document is empty", call. = FALSE)
-  }
+  check_string(x)
 
   options <- parse_options(options, xml_parse_options())
   if (grepl("<|>", x)) {
@@ -104,11 +112,15 @@ read_xml.character <- function(x, encoding = "", ..., as_html = FALSE,
   } else {
     con <- path_to_connection(x)
     if (inherits(con, "connection")) {
-      read_xml.connection(con, encoding = encoding, ..., as_html = as_html,
-        base_url = x, options = options)
+      read_xml.connection(con,
+        encoding = encoding, ..., as_html = as_html,
+        base_url = x, options = options
+      )
     } else {
-      doc <- doc_parse_file(con, encoding = encoding, as_html = as_html,
-        options = options)
+      doc <- .Call(doc_parse_file, con,
+        encoding = encoding, as_html = as_html,
+        options = options
+      )
       xml_document(doc)
     }
   }
@@ -116,20 +128,28 @@ read_xml.character <- function(x, encoding = "", ..., as_html = FALSE,
 
 #' @export
 #' @rdname read_xml
-read_xml.raw <- function(x, encoding = "", base_url = "", ...,
-                         as_html = FALSE, options = "NOBLANKS") {
+read_xml.raw <- function(x,
+                         encoding = "",
+                         base_url = "",
+                         ...,
+                         as_html = FALSE,
+                         options = "NOBLANKS") {
   options <- parse_options(options, xml_parse_options())
 
-  doc <- doc_parse_raw(x, encoding = encoding, base_url = base_url,
-    as_html = as_html, options = options)
+  doc <- .Call(doc_parse_raw, x, encoding, base_url, as_html, options)
   xml_document(doc)
 }
 
 #' @export
 #' @rdname read_xml
-read_xml.connection <- function(x, encoding = "", n = 64 * 1024,
-                                verbose = FALSE, ..., base_url = "",
-                                as_html = FALSE, options = "NOBLANKS") {
+read_xml.connection <- function(x,
+                                encoding = "",
+                                n = 64 * 1024,
+                                verbose = FALSE,
+                                ...,
+                                base_url = "",
+                                as_html = FALSE,
+                                options = "NOBLANKS") {
   options <- parse_options(options, xml_parse_options())
 
   if (!isOpen(x)) {
@@ -137,21 +157,37 @@ read_xml.connection <- function(x, encoding = "", n = 64 * 1024,
     on.exit(close(x))
   }
 
-  raw <- read_connection_(x, n)
-  read_xml.raw(raw, encoding = encoding, base_url = base_url, as_html =
-    as_html, options = options)
+  raw <- .Call(read_connection_, x, n)
+  read_xml.raw(raw,
+    encoding = encoding, base_url = base_url, as_html =
+      as_html, options = options
+  )
 }
 
 #' @export
-read_xml.response <- function(x, encoding = "", base_url = "", ...,
-                              as_html = FALSE, options = "NOBLANKS") {
-  need_package("httr")
+read_xml.response <- function(x,
+                              encoding = "",
+                              base_url = "",
+                              ...,
+                              as_html = FALSE,
+                              options = "NOBLANKS") {
+  check_installed("httr")
 
   options <- parse_options(options, xml_parse_options())
   httr::stop_for_status(x)
   content <- httr::content(x, as = "raw")
-  xml2::read_xml(content, encoding = encoding, base_url = if (nzchar(base_url)) base_url else x$url,
-    as_html = as_html, option = options, ...)
+  xml2::read_xml(content,
+    encoding = encoding, base_url = if (nzchar(base_url)) base_url else x$url,
+    as_html = as_html, option = options, ...
+  )
+}
+
+#' @export
+read_xml.textConnection <- function(x,
+                                    encoding = "",
+                                    ...) {
+  s <- paste(readLines(x), collapse = "\n")
+  read_xml.character(s, ...)
 }
 
 #' Download a HTML or XML file
@@ -169,12 +205,12 @@ read_xml.response <- function(x, encoding = "", base_url = "", ...,
 #' \dontrun{
 #' download_html("http://tidyverse.org/index.html")
 #' }
-download_xml <- function(url, file = basename(url), quiet = TRUE, mode = "wb",
-  handle = curl::new_handle()) {
-
-  if (!requireNamespace("curl", quietly = TRUE)) {
-    stop("`curl` must be installed to use `download_xml()`", call. = FALSE)
-  }
+download_xml <- function(url,
+                         file = basename(url),
+                         quiet = TRUE,
+                         mode = "wb",
+                         handle = curl::new_handle()) {
+  check_installed("curl", "to use `download_xml()`.")
 
   curl::curl_download(url, file, quiet = quiet, mode = mode, handle = handle)
 
