@@ -11,7 +11,7 @@
 #' encoding is \sQuote{UTF-8}. Available encodings are specified at
 #' <http://xmlsoft.org/html/libxml-encoding.html#xmlCharEncoding>.
 #' @param options default: \sQuote{format}. Zero or more of
-#' \Sexpr[results=rd]{xml2:::describe_options(xml2:::xml_save_options())}
+#' \Sexpr[results=rd, stage=build]{xml2:::describe_options(xml2:::xml_save_options())}
 #' @param ... additional arguments passed to methods.
 #' @export
 #' @examples
@@ -30,7 +30,7 @@ write_xml <- function(x, file, ...) {
 
 #' @export
 write_xml.xml_missing <- function(x, file, ...) {
-  abort("Missing data cannot be written")
+  cli::cli_abort("Missing data cannot be written.")
 }
 
 #' @rdname write_xml
@@ -56,7 +56,7 @@ write_xml.xml_document <- function(x, file, ..., options = "format", encoding =
 #' @export
 write_xml.xml_nodeset <- function(x, file, ..., options = "format", encoding = "UTF-8") {
   if (length(x) != 1) {
-    abort("Can only save length 1 node sets")
+    cli::cli_abort("Can only save length 1 node sets.")
   }
 
   options <- parse_options(options, xml_save_options())
@@ -104,7 +104,7 @@ write_html <- function(x, file, ...) {
 
 #' @export
 write_html.xml_missing <- function(x, file, ...) {
-  abort("Missing data cannot be written")
+  cli::cli_abort("Missing data cannot be written.")
 }
 
 #' @rdname write_xml
